You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@apr.apache.org by tr...@apache.org on 2014/01/18 14:40:25 UTC

svn commit: r1559343 - in /apr/apr/trunk: file_io/netware/ file_io/unix/ file_io/win32/ include/ locks/unix/ memory/unix/ shmem/unix/ shmem/win32/ test/ threadproc/os2/

Author: trawick
Date: Sat Jan 18 13:40:24 2014
New Revision: 1559343

URL: http://svn.apache.org/r1559343
Log:
stop using deprecated versions of APR_FOPEN_* and APR_FPROT_*

Modified:
    apr/apr/trunk/file_io/netware/filestat.c
    apr/apr/trunk/file_io/netware/mktemp.c
    apr/apr/trunk/file_io/unix/copy.c
    apr/apr/trunk/file_io/unix/fileacc.c
    apr/apr/trunk/file_io/unix/filestat.c
    apr/apr/trunk/file_io/unix/mktemp.c
    apr/apr/trunk/file_io/unix/open.c
    apr/apr/trunk/file_io/unix/readwrite.c
    apr/apr/trunk/file_io/win32/filestat.c
    apr/apr/trunk/include/apr_sdbm.h
    apr/apr/trunk/locks/unix/proc_mutex.c
    apr/apr/trunk/memory/unix/apr_pools.c
    apr/apr/trunk/shmem/unix/shm.c
    apr/apr/trunk/shmem/win32/shm.c
    apr/apr/trunk/test/sendfile.c
    apr/apr/trunk/test/testbuckets.c
    apr/apr/trunk/test/testdbm.c
    apr/apr/trunk/test/testdir.c
    apr/apr/trunk/test/testdup.c
    apr/apr/trunk/test/testfile.c
    apr/apr/trunk/test/testfilecopy.c
    apr/apr/trunk/test/testfileinfo.c
    apr/apr/trunk/test/testflock.c
    apr/apr/trunk/test/testlfs.c
    apr/apr/trunk/test/testmmap.c
    apr/apr/trunk/test/testproc.c
    apr/apr/trunk/test/tryread.c
    apr/apr/trunk/threadproc/os2/proc.c

Modified: apr/apr/trunk/file_io/netware/filestat.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/netware/filestat.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/netware/filestat.c (original)
+++ apr/apr/trunk/file_io/netware/filestat.c Sat Jan 18 13:40:24 2014
@@ -160,16 +160,16 @@ APR_DECLARE(apr_status_t) apr_file_attrs
     {
         if (attributes & APR_FILE_ATTR_READONLY)
         {
-            finfo.protection &= ~APR_UWRITE;
-            finfo.protection &= ~APR_GWRITE;
-            finfo.protection &= ~APR_WWRITE;
+            finfo.protection &= ~APR_FPROT_UWRITE;
+            finfo.protection &= ~APR_FPROT_GWRITE;
+            finfo.protection &= ~APR_FPROT_WWRITE;
         }
         else
         {
             /* ### umask this! */
-            finfo.protection |= APR_UWRITE;
-            finfo.protection |= APR_GWRITE;
-            finfo.protection |= APR_WWRITE;
+            finfo.protection |= APR_FPROT_UWRITE;
+            finfo.protection |= APR_FPROT_GWRITE;
+            finfo.protection |= APR_FPROT_WWRITE;
         }
     }
 
@@ -178,15 +178,15 @@ APR_DECLARE(apr_status_t) apr_file_attrs
         if (attributes & APR_FILE_ATTR_EXECUTABLE)
         {
             /* ### umask this! */
-            finfo.protection |= APR_UEXECUTE;
-            finfo.protection |= APR_GEXECUTE;
-            finfo.protection |= APR_WEXECUTE;
+            finfo.protection |= APR_FPROT_UEXECUTE;
+            finfo.protection |= APR_FPROT_GEXECUTE;
+            finfo.protection |= APR_FPROT_WEXECUTE;
         }
         else
         {
-            finfo.protection &= ~APR_UEXECUTE;
-            finfo.protection &= ~APR_GEXECUTE;
-            finfo.protection &= ~APR_WEXECUTE;
+            finfo.protection &= ~APR_FPROT_UEXECUTE;
+            finfo.protection &= ~APR_FPROT_GEXECUTE;
+            finfo.protection &= ~APR_FPROT_WEXECUTE;
         }
     }
 

Modified: apr/apr/trunk/file_io/netware/mktemp.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/netware/mktemp.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/netware/mktemp.c (original)
+++ apr/apr/trunk/file_io/netware/mktemp.c Sat Jan 18 13:40:24 2014
@@ -40,7 +40,7 @@ APR_DECLARE(apr_status_t) apr_file_mktem
      */
     close(fd);
     if ((rv = apr_file_open(fp, template, flags|APR_FOPEN_NOCLEANUP,
-                            APR_UREAD | APR_UWRITE, p)) == APR_SUCCESS) {
+                            APR_FPROT_UREAD | APR_FPROT_UWRITE, p)) == APR_SUCCESS) {
 
 
 	if (!(flags & APR_FOPEN_NOCLEANUP)) {

Modified: apr/apr/trunk/file_io/unix/copy.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/unix/copy.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/unix/copy.c (original)
+++ apr/apr/trunk/file_io/unix/copy.c Sat Jan 18 13:40:24 2014
@@ -29,12 +29,12 @@ static apr_status_t apr_file_transfer_co
     apr_fileperms_t perms;
 
     /* Open source file. */
-    status = apr_file_open(&s, from_path, APR_FOPEN_READ, APR_OS_DEFAULT, pool);
+    status = apr_file_open(&s, from_path, APR_FOPEN_READ, APR_FPROT_OS_DEFAULT, pool);
     if (status)
         return status;
 
     /* Maybe get its permissions. */
-    if (to_perms == APR_FILE_SOURCE_PERMS) {
+    if (to_perms == APR_FPROT_FILE_SOURCE_PERMS) {
         status = apr_file_info_get(&finfo, APR_FINFO_PROT, s);
         if (status != APR_SUCCESS && status != APR_INCOMPLETE) {
             apr_file_close(s);  /* toss any error */

Modified: apr/apr/trunk/file_io/unix/fileacc.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/unix/fileacc.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/unix/fileacc.c (original)
+++ apr/apr/trunk/file_io/unix/fileacc.c Sat Jan 18 13:40:24 2014
@@ -36,33 +36,33 @@ mode_t apr_unix_perms2mode(apr_fileperms
 {
     mode_t mode = 0;
 
-    if (perms & APR_USETID)
+    if (perms & APR_FPROT_USETID)
         mode |= S_ISUID;
-    if (perms & APR_UREAD)
+    if (perms & APR_FPROT_UREAD)
         mode |= S_IRUSR;
-    if (perms & APR_UWRITE)
+    if (perms & APR_FPROT_UWRITE)
         mode |= S_IWUSR;
-    if (perms & APR_UEXECUTE)
+    if (perms & APR_FPROT_UEXECUTE)
         mode |= S_IXUSR;
 
-    if (perms & APR_GSETID)
+    if (perms & APR_FPROT_GSETID)
         mode |= S_ISGID;
-    if (perms & APR_GREAD)
+    if (perms & APR_FPROT_GREAD)
         mode |= S_IRGRP;
-    if (perms & APR_GWRITE)
+    if (perms & APR_FPROT_GWRITE)
         mode |= S_IWGRP;
-    if (perms & APR_GEXECUTE)
+    if (perms & APR_FPROT_GEXECUTE)
         mode |= S_IXGRP;
 
 #ifdef S_ISVTX
-    if (perms & APR_WSTICKY)
+    if (perms & APR_FPROT_WSTICKY)
         mode |= S_ISVTX;
 #endif
-    if (perms & APR_WREAD)
+    if (perms & APR_FPROT_WREAD)
         mode |= S_IROTH;
-    if (perms & APR_WWRITE)
+    if (perms & APR_FPROT_WWRITE)
         mode |= S_IWOTH;
-    if (perms & APR_WEXECUTE)
+    if (perms & APR_FPROT_WEXECUTE)
         mode |= S_IXOTH;
 
     return mode;
@@ -73,33 +73,33 @@ apr_fileperms_t apr_unix_mode2perms(mode
     apr_fileperms_t perms = 0;
 
     if (mode & S_ISUID)
-        perms |= APR_USETID;
+        perms |= APR_FPROT_USETID;
     if (mode & S_IRUSR)
-        perms |= APR_UREAD;
+        perms |= APR_FPROT_UREAD;
     if (mode & S_IWUSR)
-        perms |= APR_UWRITE;
+        perms |= APR_FPROT_UWRITE;
     if (mode & S_IXUSR)
-        perms |= APR_UEXECUTE;
+        perms |= APR_FPROT_UEXECUTE;
 
     if (mode & S_ISGID)
-        perms |= APR_GSETID;
+        perms |= APR_FPROT_GSETID;
     if (mode & S_IRGRP)
-        perms |= APR_GREAD;
+        perms |= APR_FPROT_GREAD;
     if (mode & S_IWGRP)
-        perms |= APR_GWRITE;
+        perms |= APR_FPROT_GWRITE;
     if (mode & S_IXGRP)
-        perms |= APR_GEXECUTE;
+        perms |= APR_FPROT_GEXECUTE;
 
 #ifdef S_ISVTX
     if (mode & S_ISVTX)
-        perms |= APR_WSTICKY;
+        perms |= APR_FPROT_WSTICKY;
 #endif
     if (mode & S_IROTH)
-        perms |= APR_WREAD;
+        perms |= APR_FPROT_WREAD;
     if (mode & S_IWOTH)
-        perms |= APR_WWRITE;
+        perms |= APR_FPROT_WWRITE;
     if (mode & S_IXOTH)
-        perms |= APR_WEXECUTE;
+        perms |= APR_FPROT_WEXECUTE;
 
     return perms;
 }

Modified: apr/apr/trunk/file_io/unix/filestat.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/unix/filestat.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/unix/filestat.c (original)
+++ apr/apr/trunk/file_io/unix/filestat.c Sat Jan 18 13:40:24 2014
@@ -203,16 +203,16 @@ APR_DECLARE(apr_status_t) apr_file_attrs
     {
         if (attributes & APR_FILE_ATTR_READONLY)
         {
-            finfo.protection &= ~APR_UWRITE;
-            finfo.protection &= ~APR_GWRITE;
-            finfo.protection &= ~APR_WWRITE;
+            finfo.protection &= ~APR_FPROT_UWRITE;
+            finfo.protection &= ~APR_FPROT_GWRITE;
+            finfo.protection &= ~APR_FPROT_WWRITE;
         }
         else
         {
             /* ### umask this! */
-            finfo.protection |= APR_UWRITE;
-            finfo.protection |= APR_GWRITE;
-            finfo.protection |= APR_WWRITE;
+            finfo.protection |= APR_FPROT_UWRITE;
+            finfo.protection |= APR_FPROT_GWRITE;
+            finfo.protection |= APR_FPROT_WWRITE;
         }
     }
 
@@ -221,15 +221,15 @@ APR_DECLARE(apr_status_t) apr_file_attrs
         if (attributes & APR_FILE_ATTR_EXECUTABLE)
         {
             /* ### umask this! */
-            finfo.protection |= APR_UEXECUTE;
-            finfo.protection |= APR_GEXECUTE;
-            finfo.protection |= APR_WEXECUTE;
+            finfo.protection |= APR_FPROT_UEXECUTE;
+            finfo.protection |= APR_FPROT_GEXECUTE;
+            finfo.protection |= APR_FPROT_WEXECUTE;
         }
         else
         {
-            finfo.protection &= ~APR_UEXECUTE;
-            finfo.protection &= ~APR_GEXECUTE;
-            finfo.protection &= ~APR_WEXECUTE;
+            finfo.protection &= ~APR_FPROT_UEXECUTE;
+            finfo.protection &= ~APR_FPROT_GEXECUTE;
+            finfo.protection &= ~APR_FPROT_WEXECUTE;
         }
     }
 

Modified: apr/apr/trunk/file_io/unix/mktemp.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/unix/mktemp.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/unix/mktemp.c (original)
+++ apr/apr/trunk/file_io/unix/mktemp.c Sat Jan 18 13:40:24 2014
@@ -141,7 +141,7 @@ static int gettemp(char *path, apr_file_
 
     for (;;) {
         if ((rv = apr_file_open(doopen, path, flags,
-                                APR_UREAD | APR_UWRITE, p)) == APR_SUCCESS)
+                                APR_FPROT_UREAD | APR_FPROT_UWRITE, p)) == APR_SUCCESS)
             return APR_SUCCESS;
         if (!APR_STATUS_IS_EEXIST(rv))
             return rv;

Modified: apr/apr/trunk/file_io/unix/open.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/unix/open.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/unix/open.c (original)
+++ apr/apr/trunk/file_io/unix/open.c Sat Jan 18 13:40:24 2014
@@ -170,7 +170,7 @@ APR_DECLARE(apr_status_t) apr_file_open(
     }
 #endif
 
-    if (perm == APR_OS_DEFAULT) {
+    if (perm == APR_FPROT_OS_DEFAULT) {
         fd = open(fname, oflags, 0666);
     }
     else {

Modified: apr/apr/trunk/file_io/unix/readwrite.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/unix/readwrite.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/unix/readwrite.c (original)
+++ apr/apr/trunk/file_io/unix/readwrite.c Sat Jan 18 13:40:24 2014
@@ -170,7 +170,7 @@ static apr_status_t do_rotating_check(ap
             close(thefile->filedes);
             thefile->filedes = -1;
 
-            if (thefile->rotating->perm == APR_OS_DEFAULT) {
+            if (thefile->rotating->perm == APR_FPROT_OS_DEFAULT) {
                 thefile->filedes = open(thefile->fname,
                                         thefile->rotating->oflags,
                                         0666);

Modified: apr/apr/trunk/file_io/win32/filestat.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/file_io/win32/filestat.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/file_io/win32/filestat.c (original)
+++ apr/apr/trunk/file_io/win32/filestat.c Sat Jan 18 13:40:24 2014
@@ -80,11 +80,11 @@ static apr_fileperms_t convert_prot(ACCE
      */
     apr_fileperms_t prot = 0;
     if (acc & FILE_EXECUTE)
-        prot |= APR_WEXECUTE;
+        prot |= APR_FPROT_WEXECUTE;
     if (acc & FILE_WRITE_DATA)
-        prot |= APR_WWRITE;
+        prot |= APR_FPROT_WWRITE;
     if (acc & FILE_READ_DATA)
-        prot |= APR_WREAD;
+        prot |= APR_FPROT_WREAD;
     return (prot << scope);
 }
 
@@ -157,7 +157,7 @@ static apr_status_t resolve_ident(apr_fi
                           | ((wanted & APR_FINFO_LINK) ? APR_OPENLINK : 0)
                           | ((wanted & (APR_FINFO_PROT | APR_FINFO_OWNER))
                                 ? APR_READCONTROL : 0),
-                            APR_OS_DEFAULT, pool)) == APR_SUCCESS) {
+                            APR_FPROT_OS_DEFAULT, pool)) == APR_SUCCESS) {
         rv = apr_file_info_get(finfo, wanted, thefile);
         finfo->filehand = NULL;
         apr_file_close(thefile);
@@ -169,7 +169,7 @@ static apr_status_t resolve_ident(apr_fi
          */
         if ((rv = apr_file_open(&thefile, fname, APR_OPENINFO
                               | ((wanted & APR_FINFO_LINK) ? APR_OPENLINK : 0),
-                                APR_OS_DEFAULT, pool)) == APR_SUCCESS) {
+                                APR_FPROT_OS_DEFAULT, pool)) == APR_SUCCESS) {
             rv = apr_file_info_get(finfo, wanted & ~(APR_FINFO_PROT 
                                                  | APR_FINFO_OWNER),
                                  thefile);
@@ -197,10 +197,10 @@ static apr_status_t guess_protection_bit
      * The same holds on NT if a file doesn't have a DACL (e.g., on FAT)
      */
     if (finfo->protection & APR_FREADONLY) {
-        finfo->protection |= APR_WREAD | APR_WEXECUTE;
+        finfo->protection |= APR_FPROT_WREAD | APR_FPROT_WEXECUTE;
     }
     else {
-        finfo->protection |= APR_WREAD | APR_WEXECUTE | APR_WWRITE;
+        finfo->protection |= APR_FPROT_WREAD | APR_FPROT_WEXECUTE | APR_FPROT_WWRITE;
     }
     finfo->protection |= (finfo->protection << prot_scope_group)
                        | (finfo->protection << prot_scope_user);
@@ -590,7 +590,7 @@ APR_DECLARE(apr_status_t) apr_stat(apr_f
                 finfo->pool = pool;
                 finfo->filetype = 0;
                 finfo->mtime = apr_time_now();
-                finfo->protection |= APR_WREAD | APR_WEXECUTE | APR_WWRITE;
+                finfo->protection |= APR_FPROT_WREAD | APR_FPROT_WEXECUTE | APR_FPROT_WWRITE;
                 finfo->protection |= (finfo->protection << prot_scope_group) 
                                    | (finfo->protection << prot_scope_user);
                 finfo->valid |= APR_FINFO_TYPE | APR_FINFO_PROT 
@@ -782,7 +782,7 @@ APR_DECLARE(apr_status_t) apr_file_mtime
 
     rv = apr_file_open(&thefile, fname,
                        APR_FOPEN_READ | APR_WRITEATTRS,
-                       APR_OS_DEFAULT, pool);
+                       APR_FPROT_OS_DEFAULT, pool);
     if (!rv)
     {
         FILETIME file_ctime;

Modified: apr/apr/trunk/include/apr_sdbm.h
URL: http://svn.apache.org/viewvc/apr/apr/trunk/include/apr_sdbm.h?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/include/apr_sdbm.h (original)
+++ apr/apr/trunk/include/apr_sdbm.h Sat Jan 18 13:40:24 2014
@@ -69,14 +69,15 @@ typedef struct {
  * Open an sdbm database by file name
  * @param db The newly opened database
  * @param name The sdbm file to open
- * @param mode The flag values (APR_READ and APR_BINARY flags are implicit)
+ * @param mode The flag values (APR_FOPEN_READ and APR_FOPEN_BINARY flags are
+ * implicit)
  * <PRE>
- *           APR_WRITE          open for read-write access
- *           APR_CREATE         create the sdbm if it does not exist
- *           APR_TRUNCATE       empty the contents of the sdbm
- *           APR_EXCL           fail for APR_CREATE if the file exists
- *           APR_DELONCLOSE     delete the sdbm when closed
- *           APR_SHARELOCK      support locking across process/machines
+ *           APR_FOPEN_WRITE      open for read-write access
+ *           APR_FOPEN_CREATE     create the sdbm if it does not exist
+ *           APR_FOPEN_TRUNCATE   empty the contents of the sdbm
+ *           APR_FOPEN_EXCL       fail for APR_FOPEN_CREATE if the file exists
+ *           APR_FOPEN_DELONCLOSE delete the sdbm when closed
+ *           APR_FOPEN_SHARELOCK  support locking across process/machines
  * </PRE>
  * @param perms Permissions to apply to if created
  * @param p The pool to use when creating the sdbm
@@ -106,7 +107,7 @@ APR_DECLARE(apr_status_t) apr_sdbm_close
  * portably promoted to an APR_FLOCK_EXCLUSIVE lock, apr_sdbm_store and 
  * apr_sdbm_delete calls will fail if an APR_FLOCK_SHARED lock is held.
  * The apr_sdbm_lock call requires the database to be opened with the
- * APR_SHARELOCK mode value.
+ * APR_FOPEN_SHARELOCK mode value.
  */
 APR_DECLARE(apr_status_t) apr_sdbm_lock(apr_sdbm_t *db, int type);
 
@@ -154,7 +155,7 @@ APR_DECLARE(apr_status_t) apr_sdbm_delet
  * @param db The database 
  * @param key The key datum of the first record
  * @remark The keys returned are not ordered.  To traverse the list of keys
- * for an sdbm opened with APR_SHARELOCK, the caller must use apr_sdbm_lock
+ * for an sdbm opened with APR_FOPEN_SHARELOCK, the caller must use apr_sdbm_lock
  * prior to retrieving the first record, and hold the lock until after the
  * last call to apr_sdbm_nextkey.
  */

Modified: apr/apr/trunk/locks/unix/proc_mutex.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/locks/unix/proc_mutex.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/locks/unix/proc_mutex.c (original)
+++ apr/apr/trunk/locks/unix/proc_mutex.c Sat Jan 18 13:40:24 2014
@@ -570,7 +570,7 @@ static apr_status_t proc_mutex_fcntl_cre
         new_mutex->fname = apr_pstrdup(new_mutex->pool, fname);
         rv = apr_file_open(&new_mutex->interproc, new_mutex->fname,
                            APR_FOPEN_CREATE | APR_FOPEN_WRITE | APR_FOPEN_EXCL,
-                           APR_UREAD | APR_UWRITE | APR_GREAD | APR_WREAD,
+                           APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD | APR_FPROT_WREAD,
                            new_mutex->pool);
     }
     else {
@@ -707,7 +707,7 @@ static apr_status_t proc_mutex_flock_cre
         new_mutex->fname = apr_pstrdup(new_mutex->pool, fname);
         rv = apr_file_open(&new_mutex->interproc, new_mutex->fname,
                            APR_FOPEN_CREATE | APR_FOPEN_WRITE | APR_FOPEN_EXCL,
-                           APR_UREAD | APR_UWRITE,
+                           APR_FPROT_UREAD | APR_FPROT_UWRITE,
                            new_mutex->pool);
     }
     else {

Modified: apr/apr/trunk/memory/unix/apr_pools.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/memory/unix/apr_pools.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/memory/unix/apr_pools.c (original)
+++ apr/apr/trunk/memory/unix/apr_pools.c Sat Jan 18 13:40:24 2014
@@ -1526,8 +1526,9 @@ APR_DECLARE(apr_status_t) apr_pool_initi
      * may attempt to use then then non-NULL but partially set up file
      * object. */
     if (rv == APR_SUCCESS) {
-        apr_file_open(&debug_log, logpath, APR_APPEND|APR_WRITE|APR_CREATE,
-                      APR_OS_DEFAULT, global_pool);
+        apr_file_open(&debug_log, logpath,
+                      APR_FOPEN_APPEND|APR_FOPEN_WRITE|APR_FOPEN_CREATE,
+                      APR_FPROT_OS_DEFAULT, global_pool);
     }
     else {
         apr_file_open_stderr(&debug_log, global_pool);

Modified: apr/apr/trunk/shmem/unix/shm.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/shmem/unix/shm.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/sendfile.c (original)
+++ apr/apr/trunk/test/sendfile.c Sat Jan 18 13:40:24 2014
@@ -97,7 +97,7 @@ static void create_testfile(apr_pool_t *
     printf("Creating a test file...\n");
     rv = apr_file_open(&f, fname, 
                  APR_FOPEN_CREATE | APR_FOPEN_WRITE | APR_FOPEN_TRUNCATE | APR_FOPEN_BUFFERED,
-                 APR_UREAD | APR_UWRITE, p);
+                 APR_FPROT_UREAD | APR_FPROT_UWRITE, p);
     if (rv) {
         aprerr("apr_file_open()", rv);
     }

Modified: apr/apr/trunk/test/testbuckets.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testbuckets.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testbuckets.c (original)
+++ apr/apr/trunk/test/testbuckets.c Sat Jan 18 13:40:24 2014
@@ -317,7 +317,7 @@ static void test_insertfile(abts_case *t
                 apr_file_open(&f, TIF_FNAME,
                               APR_FOPEN_WRITE | APR_FOPEN_TRUNCATE
                             | APR_FOPEN_CREATE | APR_FOPEN_SPARSE,
-                              APR_OS_DEFAULT, p) == APR_SUCCESS);
+                              APR_FPROT_OS_DEFAULT, p) == APR_SUCCESS);
 
     if (apr_file_trunc(f, bignum)) {
         apr_file_close(f);
@@ -369,7 +369,7 @@ static apr_file_t *make_test_file(abts_c
     ABTS_ASSERT(tc, "create test file",
                 apr_file_open(&f, fname,
                               APR_FOPEN_READ|APR_FOPEN_WRITE|APR_FOPEN_TRUNCATE|APR_FOPEN_CREATE,
-                              APR_OS_DEFAULT, p) == APR_SUCCESS);
+                              APR_FPROT_OS_DEFAULT, p) == APR_SUCCESS);
     
     ABTS_ASSERT(tc, "write test file contents",
                 apr_file_puts(contents, f) == APR_SUCCESS);

Modified: apr/apr/trunk/test/testdbm.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testdbm.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testdbm.c (original)
+++ apr/apr/trunk/test/testdbm.c Sat Jan 18 13:40:24 2014
@@ -171,7 +171,7 @@ static void test_dbm(abts_case *tc, void
     const char *type = data;
     const char *file = apr_pstrcat(p, "data/test-", type, NULL);
 
-    rv = apr_dbm_open_ex(&db, type, file, APR_DBM_RWCREATE, APR_OS_DEFAULT, p);
+    rv = apr_dbm_open_ex(&db, type, file, APR_DBM_RWCREATE, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     if (rv != APR_SUCCESS)
@@ -187,7 +187,7 @@ static void test_dbm(abts_case *tc, void
 
     apr_dbm_close(db);
 
-    rv = apr_dbm_open_ex(&db, type, file, APR_DBM_READONLY, APR_OS_DEFAULT, p);
+    rv = apr_dbm_open_ex(&db, type, file, APR_DBM_READONLY, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     if (rv != APR_SUCCESS)

Modified: apr/apr/trunk/test/testdir.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testdir.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testdir.c (original)
+++ apr/apr/trunk/test/testdir.c Sat Jan 18 13:40:24 2014
@@ -29,7 +29,9 @@ static void test_mkdir(abts_case *tc, vo
     apr_status_t rv;
     apr_finfo_t finfo;
 
-    rv = apr_dir_make("data/testdir", APR_UREAD | APR_UWRITE | APR_UEXECUTE, p);
+    rv = apr_dir_make("data/testdir",
+                      APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_UEXECUTE,
+                      p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_stat(&finfo, "data/testdir", APR_FINFO_TYPE, p);
@@ -43,7 +45,8 @@ static void test_mkdir_recurs(abts_case 
     apr_finfo_t finfo;
 
     rv = apr_dir_make_recursive("data/one/two/three", 
-                                APR_UREAD | APR_UWRITE | APR_UEXECUTE, p);
+                                APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_UEXECUTE,
+                                p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_stat(&finfo, "data/one", APR_FINFO_TYPE, p);
@@ -105,10 +108,12 @@ static void test_mkdir_twice(abts_case *
 {
     apr_status_t rv;
 
-    rv = apr_dir_make("data/testdir", APR_UREAD | APR_UWRITE | APR_UEXECUTE, p);
+    rv = apr_dir_make("data/testdir", APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_UEXECUTE,
+                      p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
-    rv = apr_dir_make("data/testdir", APR_UREAD | APR_UWRITE | APR_UEXECUTE, p);
+    rv = apr_dir_make("data/testdir", APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_UEXECUTE,
+                      p);
     ABTS_INT_EQUAL(tc, 1, APR_STATUS_IS_EEXIST(rv));
 
     rv = apr_dir_remove("data/testdir", p);
@@ -175,12 +180,13 @@ static void test_uncleared_errno(abts_ca
     apr_dir_t *this_dir;
     apr_status_t rv; 
 
-    rv = apr_dir_make("dir1", APR_OS_DEFAULT, p);
+    rv = apr_dir_make("dir1", APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
-    rv = apr_dir_make("dir2", APR_OS_DEFAULT, p);
+    rv = apr_dir_make("dir2", APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     rv = apr_file_open(&thefile, "dir1/file1",
-                       APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE, APR_OS_DEFAULT, p);
+                       APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE,
+                       APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     rv = apr_file_close(thefile);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
@@ -224,7 +230,7 @@ static void test_rmkdir_nocwd(abts_case 
     char *cwd, *path;
 
     APR_ASSERT_SUCCESS(tc, "make temp dir",
-                       apr_dir_make("dir3", APR_OS_DEFAULT, p));
+                       apr_dir_make("dir3", APR_FPROT_OS_DEFAULT, p));
 
     APR_ASSERT_SUCCESS(tc, "obtain cwd", apr_filepath_get(&cwd, 0, p));
 

Modified: apr/apr/trunk/test/testdup.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testdup.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testdup.c (original)
+++ apr/apr/trunk/test/testdup.c Sat Jan 18 13:40:24 2014
@@ -35,7 +35,7 @@ static void test_file_dup(abts_case *tc,
     /* First, create a new file, empty... */
     rv = apr_file_open(&file1, FILEPATH "testdup.file", 
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE |
-                       APR_FOPEN_DELONCLOSE, APR_OS_DEFAULT, p);
+                       APR_FOPEN_DELONCLOSE, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     ABTS_PTR_NOTNULL(tc, file1);
 
@@ -66,7 +66,7 @@ static void test_file_readwrite(abts_cas
     /* First, create a new file, empty... */
     rv = apr_file_open(&file1, FILEPATH "testdup.readwrite.file", 
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE |
-                       APR_FOPEN_DELONCLOSE, APR_OS_DEFAULT, p);
+                       APR_FOPEN_DELONCLOSE, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     ABTS_PTR_NOTNULL(tc, file1);
 
@@ -107,7 +107,7 @@ static void test_dup2(abts_case *tc, voi
 
     rv = apr_file_open(&testfile, FILEPATH "testdup2.file", 
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE |
-                       APR_FOPEN_DELONCLOSE, APR_OS_DEFAULT, p);
+                       APR_FOPEN_DELONCLOSE, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     ABTS_PTR_NOTNULL(tc, testfile);
 
@@ -144,7 +144,7 @@ static void test_dup2_readwrite(abts_cas
 
     rv = apr_file_open(&testfile, FILEPATH "testdup2.readwrite.file", 
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE |
-                       APR_FOPEN_DELONCLOSE, APR_OS_DEFAULT, p);
+                       APR_FOPEN_DELONCLOSE, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     ABTS_PTR_NOTNULL(tc, testfile);
 

Modified: apr/apr/trunk/test/testfile.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testfile.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testfile.c (original)
+++ apr/apr/trunk/test/testfile.c Sat Jan 18 13:40:24 2014
@@ -39,7 +39,7 @@ static void test_open_noreadwrite(abts_c
 
     rv = apr_file_open(&thefile, FILENAME,
                        APR_FOPEN_CREATE | APR_FOPEN_EXCL,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_TRUE(tc, rv != APR_SUCCESS);
     ABTS_INT_EQUAL(tc, 1, APR_STATUS_IS_EACCES(rv));
     ABTS_PTR_EQUAL(tc, NULL, thefile); 
@@ -52,7 +52,7 @@ static void test_open_excl(abts_case *tc
 
     rv = apr_file_open(&thefile, FILENAME,
                        APR_FOPEN_CREATE | APR_FOPEN_EXCL | APR_FOPEN_WRITE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_TRUE(tc, rv != APR_SUCCESS);
     ABTS_INT_EQUAL(tc, 1, APR_STATUS_IS_EEXIST(rv));
     ABTS_PTR_EQUAL(tc, NULL, thefile); 
@@ -65,7 +65,7 @@ static void test_open_read(abts_case *tc
 
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_READ,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     ABTS_PTR_NOTNULL(tc, filetest);
     apr_file_close(filetest);
@@ -97,7 +97,7 @@ static void test_read(abts_case *tc, voi
     
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_READ,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
 
     APR_ASSERT_SUCCESS(tc, "Opening test file " FILENAME, rv);
     rv = apr_file_read(filetest, str, &nbytes);
@@ -115,7 +115,7 @@ static void test_readzero(abts_case *tc,
     char *str = NULL;
     apr_file_t *filetest;
     
-    rv = apr_file_open(&filetest, FILENAME, APR_FOPEN_READ, APR_OS_DEFAULT, p);
+    rv = apr_file_open(&filetest, FILENAME, APR_FOPEN_READ, APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "Opening test file " FILENAME, rv);
 
     rv = apr_file_read(filetest, str, &nbytes);
@@ -133,7 +133,7 @@ static void test_filename(abts_case *tc,
     
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_READ,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     APR_ASSERT_SUCCESS(tc, "Opening test file " FILENAME, rv);
 
     rv = apr_file_name_get(&str, filetest);
@@ -152,7 +152,7 @@ static void test_fileclose(abts_case *tc
     
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_READ,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     APR_ASSERT_SUCCESS(tc, "Opening test file " FILENAME, rv);
 
     rv = apr_file_close(filetest);
@@ -171,7 +171,7 @@ static void test_file_remove(abts_case *
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_open(&filetest, FILENAME, APR_FOPEN_READ,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, 1, APR_STATUS_IS_ENOENT(rv));
 }
 
@@ -183,7 +183,7 @@ static void test_open_write(abts_case *t
     filetest = NULL;
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_WRITE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, 1, APR_STATUS_IS_ENOENT(rv));
     ABTS_PTR_EQUAL(tc, NULL, filetest);
 }
@@ -196,7 +196,7 @@ static void test_open_writecreate(abts_c
     filetest = NULL;
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_WRITE | APR_FOPEN_CREATE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     apr_file_close(filetest);
@@ -210,7 +210,7 @@ static void test_write(abts_case *tc, vo
 
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_WRITE | APR_FOPEN_CREATE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_write(filetest, TESTSTR, &bytes);
@@ -227,7 +227,7 @@ static void test_open_readwrite(abts_cas
     filetest = NULL;
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_READ | APR_FOPEN_WRITE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     ABTS_PTR_NOTNULL(tc, filetest);
 
@@ -244,7 +244,7 @@ static void test_seek(abts_case *tc, voi
 
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_READ,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     APR_ASSERT_SUCCESS(tc, "Open test file " FILENAME, rv);
 
     rv = apr_file_read(filetest, str, &nbytes);
@@ -268,7 +268,7 @@ static void test_seek(abts_case *tc, voi
        buffered files. */
     rv = apr_file_open(&filetest, FILENAME,
                        APR_FOPEN_READ | APR_FOPEN_BUFFERED,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     APR_ASSERT_SUCCESS(tc, "Open test file " FILENAME, rv);
 
     offset = -5;
@@ -293,7 +293,7 @@ static void test_userdata_set(abts_case 
 
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_WRITE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_data_set(filetest, "This is a test",
@@ -311,7 +311,7 @@ static void test_userdata_get(abts_case 
 
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_WRITE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_data_set(filetest, "This is a test",
@@ -334,7 +334,7 @@ static void test_userdata_getnokey(abts_
 
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_WRITE,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_data_get(&teststr, "nokey", filetest);
@@ -352,7 +352,7 @@ static void test_buffer_set_get(abts_cas
 
     rv = apr_file_open(&filetest, FILENAME, 
                        APR_FOPEN_WRITE | APR_FOPEN_BUFFERED,
-                       APR_UREAD | APR_UWRITE | APR_GREAD, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     bufsize = apr_file_buffer_size_get(filetest);
@@ -467,7 +467,7 @@ static void test_bigread(abts_case *tc, 
      */
     rv = apr_file_open(&f, "data/created_file", 
                        APR_FOPEN_CREATE | APR_FOPEN_WRITE | APR_FOPEN_TRUNCATE,
-                       APR_UREAD | APR_UWRITE, p);
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     nbytes = APR_BUFFERSIZE;
@@ -511,7 +511,8 @@ static void test_mod_neg(abts_case *tc, 
     const char *fname = "data/modneg.dat";
 
     rv = apr_file_open(&f, fname, 
-                       APR_FOPEN_CREATE | APR_FOPEN_WRITE, APR_UREAD | APR_UWRITE, p);
+                       APR_FOPEN_CREATE | APR_FOPEN_WRITE,
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     s = "body56789\n";
@@ -611,7 +612,7 @@ static void test_puts(abts_case *tc, voi
     APR_ASSERT_SUCCESS(tc, "open file for writing",
                        apr_file_open(&f, fname, 
                                      APR_FOPEN_WRITE|APR_FOPEN_CREATE|APR_FOPEN_TRUNCATE,
-                                     APR_OS_DEFAULT, p));
+                                     APR_FPROT_OS_DEFAULT, p));
     
     APR_ASSERT_SUCCESS(tc, "write line to file", 
                        apr_file_puts(LINE1, f));
@@ -634,7 +635,7 @@ static void test_writev(abts_case *tc, v
     APR_ASSERT_SUCCESS(tc, "open file for writing",
                        apr_file_open(&f, fname, 
                                      APR_FOPEN_WRITE|APR_FOPEN_CREATE|APR_FOPEN_TRUNCATE,
-                                     APR_OS_DEFAULT, p));
+                                     APR_FPROT_OS_DEFAULT, p));
     
     vec[0].iov_base = LINE1;
     vec[0].iov_len = strlen(LINE1);
@@ -676,7 +677,7 @@ static void test_writev_full(abts_case *
     APR_ASSERT_SUCCESS(tc, "open file for writing",
                        apr_file_open(&f, fname, 
                                      APR_FOPEN_WRITE|APR_FOPEN_CREATE|APR_FOPEN_TRUNCATE,
-                                     APR_OS_DEFAULT, p));
+                                     APR_FPROT_OS_DEFAULT, p));
     
     vec[0].iov_base = LINE1;
     vec[0].iov_len = strlen(LINE1);
@@ -712,7 +713,7 @@ static void test_writev_buffered(abts_ca
     APR_ASSERT_SUCCESS(tc, "open file for writing",
                        apr_file_open(&f, fname,
                                      APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_TRUNCATE |
-                                     APR_FOPEN_BUFFERED, APR_OS_DEFAULT, p));
+                                     APR_FOPEN_BUFFERED, APR_FPROT_OS_DEFAULT, p));
 
     nbytes = strlen(TESTSTR);
     APR_ASSERT_SUCCESS(tc, "buffered write",
@@ -746,7 +747,7 @@ static void test_writev_buffered_seek(ab
     APR_ASSERT_SUCCESS(tc, "open file for writing",
                        apr_file_open(&f, fname,
                                      APR_FOPEN_WRITE | APR_FOPEN_READ | APR_FOPEN_BUFFERED,
-                                     APR_OS_DEFAULT, p));
+                                     APR_FPROT_OS_DEFAULT, p));
 
     rv = apr_file_read(f, str, &nbytes);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
@@ -784,7 +785,8 @@ static void test_truncate(abts_case *tc,
     apr_file_remove(fname, p);
 
     rv = apr_file_open(&f, fname,
-                       APR_FOPEN_CREATE | APR_FOPEN_WRITE, APR_UREAD | APR_UWRITE, p);
+                       APR_FOPEN_CREATE | APR_FOPEN_WRITE,
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     
     s = "some data";
@@ -797,7 +799,8 @@ static void test_truncate(abts_case *tc,
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_open(&f, fname,
-                       APR_FOPEN_TRUNCATE | APR_FOPEN_WRITE, APR_UREAD | APR_UWRITE, p);
+                       APR_FOPEN_TRUNCATE | APR_FOPEN_WRITE,
+                       APR_FPROT_UREAD | APR_FPROT_UWRITE, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_close(f);
@@ -826,7 +829,7 @@ static void test_file_trunc(abts_case *t
     rv = apr_file_open(&f, fname,
                         APR_FOPEN_CREATE | APR_FOPEN_READ |
                         APR_FOPEN_WRITE,
-                        APR_UREAD | APR_UWRITE, p);
+                        APR_FPROT_UREAD | APR_FPROT_UWRITE, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     s = "some data";
@@ -848,7 +851,7 @@ static void test_file_trunc(abts_case *t
     rv = apr_file_open(&f, fname,
                         APR_FOPEN_CREATE | APR_FOPEN_READ |
                         APR_FOPEN_WRITE | APR_FOPEN_BUFFERED,
-                        APR_UREAD | APR_UWRITE, p);
+                        APR_FPROT_UREAD | APR_FPROT_UWRITE, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     nbytes = strlen(s);
@@ -879,7 +882,7 @@ static void test_bigfprintf(abts_case *t
     APR_ASSERT_SUCCESS(tc, "open test file",
                        apr_file_open(&f, fname,
                                      APR_FOPEN_CREATE|APR_FOPEN_WRITE,
-                                     APR_UREAD|APR_UWRITE, p));
+                                     APR_FPROT_UREAD|APR_FPROT_UWRITE, p));
     
 
     to_write = malloc(HUGE_STRING_LEN + 3);
@@ -912,7 +915,7 @@ static void test_fail_write_flush(abts_c
     APR_ASSERT_SUCCESS(tc, "open test file",
                        apr_file_open(&f, fname,
                                      APR_FOPEN_CREATE|APR_FOPEN_READ|APR_FOPEN_BUFFERED,
-                                     APR_UREAD|APR_UWRITE, p));
+                                     APR_FPROT_UREAD|APR_FPROT_UWRITE, p));
 
     memset(buf, 'A', sizeof buf);
 
@@ -942,7 +945,7 @@ static void test_fail_read_flush(abts_ca
     APR_ASSERT_SUCCESS(tc, "open test file",
                        apr_file_open(&f, fname,
                                      APR_FOPEN_CREATE|APR_FOPEN_READ|APR_FOPEN_BUFFERED,
-                                     APR_UREAD|APR_UWRITE, p));
+                                     APR_FPROT_UREAD|APR_FPROT_UWRITE, p));
 
     /* this write should be buffered. */
     APR_ASSERT_SUCCESS(tc, "buffered write should succeed",
@@ -991,7 +994,7 @@ static void test_xthread(abts_case *tc, 
 
     APR_ASSERT_SUCCESS(tc, "open test file",
                        apr_file_open(&f, fname, flags,
-                                     APR_UREAD|APR_UWRITE, p));
+                                     APR_FPROT_UREAD|APR_FPROT_UWRITE, p));
 
     APR_ASSERT_SUCCESS(tc, "write should succeed",
                        apr_file_puts("hello", f));
@@ -1000,7 +1003,7 @@ static void test_xthread(abts_case *tc, 
     
     APR_ASSERT_SUCCESS(tc, "open test file",
                        apr_file_open(&f, fname, flags,
-                                     APR_UREAD|APR_UWRITE, p));
+                                     APR_FPROT_UREAD|APR_FPROT_UWRITE, p));
 
     /* Seek to the end. */
     {

Modified: apr/apr/trunk/test/testfilecopy.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testfilecopy.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testfilecopy.c (original)
+++ apr/apr/trunk/test/testfilecopy.c Sat Jan 18 13:40:24 2014
@@ -63,7 +63,7 @@ static void copy_short_file(abts_case *t
     apr_file_remove("data/file_copy.txt", p);
     
     copy_helper(tc, "data/file_datafile.txt", "data/file_copy.txt", 
-                APR_FILE_SOURCE_PERMS, 0, p);
+                APR_FPROT_FILE_SOURCE_PERMS, 0, p);
     rv = apr_file_remove("data/file_copy.txt", p);
     APR_ASSERT_SUCCESS(tc, "Couldn't remove copy file", rv);
 }
@@ -80,10 +80,10 @@ static void copy_over_existing(abts_case
      * this works.
      */
     copy_helper(tc, "data/file_datafile.txt", "data/file_copy.txt", 
-                APR_FILE_SOURCE_PERMS, 0, p);
+                APR_FPROT_FILE_SOURCE_PERMS, 0, p);
     
     copy_helper(tc, "data/mmap_datafile.txt", "data/file_copy.txt", 
-                APR_FILE_SOURCE_PERMS, 0, p);
+                APR_FPROT_FILE_SOURCE_PERMS, 0, p);
   
     rv = apr_file_remove("data/file_copy.txt", p);
     APR_ASSERT_SUCCESS(tc, "Couldn't remove copy file", rv);
@@ -97,7 +97,7 @@ static void append_nonexist(abts_case *t
     apr_file_remove("data/file_copy.txt", p);
 
     copy_helper(tc, "data/file_datafile.txt", "data/file_copy.txt", 
-                APR_FILE_SOURCE_PERMS, 0, p);
+                APR_FPROT_FILE_SOURCE_PERMS, 0, p);
     rv = apr_file_remove("data/file_copy.txt", p);
     APR_ASSERT_SUCCESS(tc, "Couldn't remove copy file", rv);
 }
@@ -114,10 +114,10 @@ static void append_exist(abts_case *tc, 
      * this works.
      */
     copy_helper(tc, "data/file_datafile.txt", "data/file_copy.txt", 
-                APR_FILE_SOURCE_PERMS, 0, p);
+                APR_FPROT_FILE_SOURCE_PERMS, 0, p);
     
     copy_helper(tc, "data/mmap_datafile.txt", "data/file_copy.txt", 
-                APR_FILE_SOURCE_PERMS, 1, p);
+                APR_FPROT_FILE_SOURCE_PERMS, 1, p);
   
     rv = apr_file_remove("data/file_copy.txt", p);
     APR_ASSERT_SUCCESS(tc, "Couldn't remove copy file", rv);

Modified: apr/apr/trunk/test/testfileinfo.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testfileinfo.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testfileinfo.c (original)
+++ apr/apr/trunk/test/testfileinfo.c Sat Jan 18 13:40:24 2014
@@ -109,7 +109,7 @@ static void test_info_get(abts_case *tc,
     apr_finfo_t finfo;
     apr_status_t rv;
 
-    rv = apr_file_open(&thefile, FILENAME, APR_FOPEN_READ, APR_OS_DEFAULT, p);
+    rv = apr_file_open(&thefile, FILENAME, APR_FOPEN_READ, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     rv = apr_file_info_get(&finfo, APR_FINFO_NORM, thefile);
@@ -155,7 +155,7 @@ static void test_stat_eq_finfo(abts_case
     apr_finfo_t stat_finfo;
     apr_status_t rv;
 
-    rv = apr_file_open(&thefile, FILENAME, APR_FOPEN_READ, APR_OS_DEFAULT, p);
+    rv = apr_file_open(&thefile, FILENAME, APR_FOPEN_READ, APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     rv = apr_file_info_get(&finfo, APR_FINFO_NORM, thefile);
 
@@ -182,7 +182,7 @@ static void test_buffered_write_size(abt
     rv = apr_file_open(&thefile, NEWFILENAME,
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_TRUNCATE
                        | APR_FOPEN_BUFFERED | APR_FOPEN_DELONCLOSE,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "open file", rv);
 
     /* A funny thing happened to me the other day: I wrote something
@@ -215,7 +215,7 @@ static void test_mtime_set(abts_case *tc
     rv = apr_file_open(&thefile, NEWFILENAME,
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_TRUNCATE
                        | APR_FOPEN_BUFFERED | APR_FOPEN_DELONCLOSE,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "open file", rv);
 
     /* Check that the current mtime is not the epoch */

Modified: apr/apr/trunk/test/testflock.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testflock.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testflock.c (original)
+++ apr/apr/trunk/test/testflock.c Sat Jan 18 13:40:24 2014
@@ -64,7 +64,7 @@ static void test_withlock(abts_case *tc,
     int code;
     
     rv = apr_file_open(&file, TESTFILE, APR_FOPEN_WRITE|APR_FOPEN_CREATE,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "Could not create file.", rv);
     ABTS_PTR_NOTNULL(tc, file);
 

Modified: apr/apr/trunk/test/testlfs.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testlfs.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testlfs.c (original)
+++ apr/apr/trunk/test/testlfs.c Sat Jan 18 13:40:24 2014
@@ -50,7 +50,7 @@ static void test_open(abts_case *tc, voi
     apr_finfo_t testsize;
     apr_status_t rv;
 
-    rv = apr_dir_make(TESTDIR, APR_OS_DEFAULT, p);
+    rv = apr_dir_make(TESTDIR, APR_FPROT_OS_DEFAULT, p);
     if (rv && !APR_STATUS_IS_EEXIST(rv)) {
         APR_ASSERT_SUCCESS(tc, "make test directory", rv);
     }
@@ -58,7 +58,7 @@ static void test_open(abts_case *tc, voi
     /* First attempt a 1MB sparse file so we don't tax the poor test box */
     rv = apr_file_open(&f, TESTFN, APR_FOPEN_CREATE | APR_FOPEN_WRITE
                                  | APR_FOPEN_TRUNCATE | APR_FOPEN_SPARSE,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
 
     APR_ASSERT_SUCCESS(tc, "open file", rv);
 
@@ -114,7 +114,7 @@ static void test_reopen(abts_case *tc, v
     PRECOND;
     
     rv = apr_file_open(&fh, TESTFN, APR_FOPEN_SPARSE | APR_FOPEN_READ,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "re-open 8GB file", rv);
 
     APR_ASSERT_SUCCESS(tc, "file_info_get failed",
@@ -180,7 +180,7 @@ static void test_append(abts_case *tc, v
 
     rv = apr_file_open(&fh, TESTFN, APR_FOPEN_SPARSE | APR_FOPEN_WRITE 
                                   | APR_FOPEN_APPEND, 
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "open 8GB file for append", rv);
 
     APR_ASSERT_SUCCESS(tc, "append to 8GB file",
@@ -204,7 +204,7 @@ static void test_seek(abts_case *tc, voi
     PRECOND;
     
     rv = apr_file_open(&fh, TESTFN, APR_FOPEN_SPARSE | APR_FOPEN_WRITE,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "open 8GB file for writing", rv);
 
     pos = 0;
@@ -232,7 +232,7 @@ static void test_write(abts_case *tc, vo
     PRECOND;
 
     rv = apr_file_open(&fh, TESTFN, APR_FOPEN_SPARSE | APR_FOPEN_WRITE,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "re-open 8GB file", rv);
 
     APR_ASSERT_SUCCESS(tc, "seek to 8GB - 4", 
@@ -259,7 +259,7 @@ static void test_mmap(abts_case *tc, voi
     PRECOND;
 
     rv = apr_file_open(&fh, TESTFN, APR_FOPEN_SPARSE | APR_FOPEN_READ,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "open 8gb file for mmap", rv);
     
     APR_ASSERT_SUCCESS(tc, "mmap 8GB file",
@@ -304,7 +304,7 @@ static void test_buffered(abts_case *tc,
     rv = apr_file_open(&f, TESTBUFFN, APR_FOPEN_CREATE | APR_FOPEN_WRITE
                                     | APR_FOPEN_TRUNCATE | APR_FOPEN_BUFFERED
                                     | APR_FOPEN_SPARSE,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     APR_ASSERT_SUCCESS(tc, "open buffered file", rv);
 
     APR_ASSERT_SUCCESS(tc, "truncate to 8GB",

Modified: apr/apr/trunk/test/testmmap.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testmmap.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testmmap.c (original)
+++ apr/apr/trunk/test/testmmap.c Sat Jan 18 13:40:24 2014
@@ -84,7 +84,8 @@ static void test_file_open(abts_case *tc
 {
     apr_status_t rv;
 
-    rv = apr_file_open(&thefile, file1, APR_FOPEN_READ, APR_UREAD | APR_GREAD, p);
+    rv = apr_file_open(&thefile, file1, APR_FOPEN_READ,
+                       APR_FPROT_UREAD | APR_FPROT_GREAD, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     ABTS_PTR_NOTNULL(tc, thefile);
 }

Modified: apr/apr/trunk/test/testproc.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/testproc.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/testproc.c (original)
+++ apr/apr/trunk/test/testproc.c Sat Jan 18 13:40:24 2014
@@ -96,15 +96,15 @@ static void test_file_redir(abts_case *t
     testfile = NULL;
     rv = apr_file_open(&testfile, "data/stdin",
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_EXCL,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     rv = apr_file_open(&testout, "data/stdout",
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_EXCL,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
     rv = apr_file_open(&testerr, "data/stderr",
                        APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_EXCL,
-                       APR_OS_DEFAULT, p);
+                       APR_FPROT_OS_DEFAULT, p);
     ABTS_INT_EQUAL(tc, APR_SUCCESS, rv);
 
     length = strlen(TESTSTR);

Modified: apr/apr/trunk/test/tryread.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/tryread.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/test/tryread.c (original)
+++ apr/apr/trunk/test/tryread.c Sat Jan 18 13:40:24 2014
@@ -33,7 +33,7 @@ int main(int argc, const char * const *a
     apr_initialize();
     apr_pool_create(&p, NULL);
 
-    if (apr_file_open(&file, TESTFILE, APR_FOPEN_WRITE, APR_OS_DEFAULT, p)
+    if (apr_file_open(&file, TESTFILE, APR_FOPEN_WRITE, APR_FPROT_OS_DEFAULT, p)
         != APR_SUCCESS) {
         
         exit(UNEXPECTED_ERROR);

Modified: apr/apr/trunk/threadproc/os2/proc.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/threadproc/os2/proc.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/threadproc/os2/proc.c (original)
+++ apr/apr/trunk/threadproc/os2/proc.c Sat Jan 18 13:40:24 2014
@@ -380,7 +380,8 @@ APR_DECLARE(apr_status_t) apr_proc_creat
         strcpy(interpreter, "#!" SHELL_PATH);
         extra_arg = "/C";
     } else if (stricmp(extension, ".exe") != 0) {
-        status = apr_file_open(&progfile, progname, APR_READ|APR_BUFFERED, 0, pool);
+        status = apr_file_open(&progfile, progname,
+                               APR_FOPEN_READ|APR_FOPEN_BUFFERED, 0, pool);
 
         if (status != APR_SUCCESS && APR_STATUS_IS_ENOENT(status)) {
             progname = apr_pstrcat(pool, progname, ".exe", NULL);
--- apr/apr/trunk/shmem/unix/shm.c (original)
+++ apr/apr/trunk/shmem/unix/shm.c Sat Jan 18 13:40:24 2014
@@ -122,8 +122,8 @@ APR_DECLARE(apr_status_t) apr_shm_create
         new_m->filename = NULL;
     
 #if APR_USE_SHMEM_MMAP_ZERO
-        status = apr_file_open(&file, "/dev/zero", APR_READ | APR_WRITE, 
-                               APR_OS_DEFAULT, pool);
+        status = apr_file_open(&file, "/dev/zero", APR_FOPEN_READ | APR_FOPEN_WRITE, 
+                               APR_FPROT_OS_DEFAULT, pool);
         if (status != APR_SUCCESS) {
             return status;
         }
@@ -231,10 +231,10 @@ APR_DECLARE(apr_status_t) apr_shm_create
         status = APR_SUCCESS;
     
 #if APR_USE_SHMEM_MMAP_TMP
-        /* FIXME: Is APR_OS_DEFAULT sufficient? */
+        /* FIXME: Is APR_FPROT_OS_DEFAULT sufficient? */
         status = apr_file_open(&file, filename, 
-                               APR_READ | APR_WRITE | APR_CREATE | APR_EXCL,
-                               APR_OS_DEFAULT, pool);
+                               APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_EXCL,
+                               APR_FPROT_OS_DEFAULT, pool);
         if (status != APR_SUCCESS) {
             return status;
         }
@@ -269,7 +269,7 @@ APR_DECLARE(apr_status_t) apr_shm_create
         }
 
         status = apr_os_file_put(&file, &tmpfd,
-                                 APR_READ | APR_WRITE | APR_CREATE | APR_EXCL,
+                                 APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_EXCL,
                                  pool); 
         if (status != APR_SUCCESS) {
             return status;
@@ -304,10 +304,10 @@ APR_DECLARE(apr_status_t) apr_shm_create
 #elif APR_USE_SHMEM_SHMGET
         new_m->realsize = reqsize;
 
         /* FIXME: APR_OS_DEFAULT is too permissive, switch to 600 I think. */
         status = apr_file_open(&file, filename, 
                                APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_EXCL,
-                               APR_OS_DEFAULT, pool);
+                               APR_FPROT_OS_DEFAULT, pool);
         if (status != APR_SUCCESS) {
             return status;
         }
@@ -399,7 +399,7 @@ APR_DECLARE(apr_status_t) apr_shm_remove
 #elif APR_USE_SHMEM_SHMGET
     /* Presume that the file already exists; just open for writing */    
     status = apr_file_open(&file, filename, APR_FOPEN_WRITE,
-                           APR_OS_DEFAULT, pool);
+                           APR_FPROT_OS_DEFAULT, pool);
     if (status) {
         return status;
     }
@@ -491,8 +491,8 @@ APR_DECLARE(apr_status_t) apr_shm_attach
         new_m->filename = apr_pstrdup(pool, filename);
 
         status = apr_file_open(&file, filename, 
-                               APR_READ | APR_WRITE,
-                               APR_OS_DEFAULT, pool);
+                               APR_FOPEN_READ | APR_FOPEN_WRITE,
+                               APR_FPROT_OS_DEFAULT, pool);
         if (status != APR_SUCCESS) {
             return status;
         }
@@ -544,7 +544,7 @@ APR_DECLARE(apr_status_t) apr_shm_attach
         new_m = apr_palloc(pool, sizeof(apr_shm_t));
 
         status = apr_file_open(&file, filename, 
-                               APR_FOPEN_READ, APR_OS_DEFAULT, pool);
+                               APR_FOPEN_READ, APR_FPROT_OS_DEFAULT, pool);
         if (status != APR_SUCCESS) {
             return status;
         }
@@ -304,10 +304,10 @@ APR_DECLARE(apr_status_t) apr_shm_create
         new_m->realsize = reqsize;
 
-        /* FIXME: APR_OS_DEFAULT is too permissive, switch to 600 I think. */
+        /* FIXME: APR_FPROT_OS_DEFAULT is too permissive, switch to 600 I think. */
         status = apr_file_open(&file, filename, 
                                APR_FOPEN_WRITE | APR_FOPEN_CREATE | APR_FOPEN_EXCL,

Modified: apr/apr/trunk/shmem/win32/shm.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/shmem/win32/shm.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================
--- apr/apr/trunk/shmem/win32/shm.c (original)
+++ apr/apr/trunk/shmem/win32/shm.c Sat Jan 18 13:40:24 2014
@@ -158,13 +158,13 @@ APR_DECLARE(apr_status_t) apr_shm_create
         int global;
 
         /* Do file backed, which is not an inherited handle 
          * While we could open APR_EXCL, it doesn't seem that Unix
          * ever did.  Ignore that error here, but fail later when
          * we discover we aren't the creator of the file map object.
          */
         rv = apr_file_open(&f, file,
-                           APR_READ | APR_WRITE | APR_BINARY | APR_CREATE,
-                           APR_UREAD | APR_UWRITE, pool);
+                           APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_BINARY | APR_FOPEN_CREATE,
+                           APR_FPROT_UREAD | APR_FPROT_UWRITE, pool);
         if ((rv != APR_SUCCESS)
                 || ((rv = apr_os_file_get(&hFile, f)) != APR_SUCCESS)) {
             return rv;
@@ -158,13 +158,13 @@ APR_DECLARE(apr_status_t) apr_shm_create
 
         /* Do file backed, which is not an inherited handle 
-         * While we could open APR_EXCL, it doesn't seem that Unix
+         * While we could open APR_FOPEN_EXCL, it doesn't seem that Unix
          * ever did.  Ignore that error here, but fail later when
          * we discover we aren't the creator of the file map object.

Modified: apr/apr/trunk/test/sendfile.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/test/sendfile.c?rev=1559343&r1=1559342&r2=1559343&view=diff
==============================================================================